==> cwyodmodules-0.3.56.tar.gz: cwyodmodules-0.3.56/tests/test_batch.py <==
"""
Tests for the batch utilities module.
"""
import pytest
from unittest.mock import Mock, AsyncMock, patch, MagicMock
import os
from typing import Dict, Any, List

# Import batch utilities - we'll test the structure and mock the actual implementations
# since the actual implementations may have complex dependencies


class TestBatchUtilitiesStructure:
    """Test class for batch utilities structure and basic functionality."""

    @pytest.mark.batch
    @pytest.mark.unit
    def test_batch_utilities_imports(self):
        """Test that batch utilities can be imported."""
        # Test that the main batch utilities module can be imported
        try:
            import cwyodmodules.batch.utilities
            assert True
        except ImportError as e:
            pytest.fail(f"Failed to import batch utilities: {e}")

    @pytest.mark.batch
    @pytest.mark.unit
    def test_helpers_structure(self):
        """Test helpers module structure."""
        try:
            import cwyodmodules.batch.utilities.helpers
            assert True
        except ImportError as e:
            pytest.fail(f"Failed to import helpers: {e}")

    @pytest.mark.batch
    @pytest.mark.unit
    def test_chat_history_structure(self):
        """Test chat history module structure."""
        try:
            import cwyodmodules.batch.utilities.chat_history
            assert True
        except ImportError as e:
            pytest.fail(f"Failed to import chat history: {e}")

    @pytest.mark.batch
    @pytest.mark.unit
    def test_document_loading_structure(self):
        """Test document loading module structure."""
        try:
            import cwyodmodules.batch.utilities.document_loading
            assert True
        except ImportError as e:
            pytest.fail(f"Failed to import document loading: {e}")

    @pytest.mark.batch
    @pytest.mark.unit
    def test_document_chunking_structure(self):
        """Test document chunking module structure."""
        try:
            import cwyodmodules.batch.utilities.document_chunking
            assert True
        except ImportError as e:
            pytest.fail(f"Failed to import document chunking: {e}")

    @pytest.mark.batch
    @pytest.mark.unit
    def test_search_structure(self):
        """Test search module structure."""
        try:
            import cwyodmodules.batch.utilities.search
            assert True
        except ImportError as e:
            pytest.fail(f"Failed to import search: {e}")

    @pytest.mark.batch
    @pytest.mark.unit
    def test_orchestrator_structure(self):
        """Test orchestrator module structure."""
        try:
            import cwyodmodules.batch.utilities.orchestrator
            assert True
        except ImportError as e:
            pytest.fail(f"Failed to import orchestrator: {e}")


class TestBatchHelpers:
    """Test class for batch helper functions."""

    @pytest.mark.batch
    @pytest.mark.unit
    def test_config_helper_mock(self, mock_logger):
        """Test config helper functionality with mocks."""
        with patch('cwyodmodules.batch.utilities.helpers.config.config_helper.ConfigHelper') as mock_config_helper:
            mock_config = Mock()
            mock_config.enable_chat_history = True
            mock_config_helper.get_active_config_or_default.return_value = mock_config
            
            # Test that config helper can be called
            config = mock_config_helper.get_active_config_or_default()
            assert config.enable_chat_history is True

    @pytest.mark.batch
    @pytest.mark.unit
    def test_env_helper_mock(self, mock_logger):
        """Test environment helper functionality with mocks."""
        with patch('cwyodmodules.batch.utilities.helpers.env_helper.EnvHelper') as mock_env_helper_class:
            mock_env_helper = Mock()
            mock_env_helper.LOG_EXECUTION = True
            mock_env_helper.LOG_ARGS = True
            mock_env_helper.LOG_RESULT = True
            mock_env_helper.is_auth_type_keys.return_value = True
            mock_env_helper.AZURE_OPENAI_ENDPOINT = "https://test.openai.azure.com/"
            mock_env_helper.AZURE_OPENAI_API_VERSION = "2024-02-15-preview"
            mock_env_helper.AZURE_OPENAI_API_KEY = "test-key"
            
            mock_env_helper_class.return_value = mock_env_helper
            
            # Test that env helper can be instantiated and used
            env_helper = mock_env_helper_class()
            assert env_helper.LOG_EXECUTION is True
            assert env_helper.is_auth_type_keys() is True
            assert env_helper.AZURE_OPENAI_ENDPOINT == "https://test.openai.azure.com/"


class TestBatchChatHistory:
    """Test class for batch chat history functionality."""

    @pytest.mark.batch
    @pytest.mark.unit
    def test_database_factory_mock(self, mock_logger):
        """Test database factory functionality with mocks."""
        with patch('cwyodmodules.batch.utilities.chat_history.database_factory.DatabaseFactory') as mock_factory:
            mock_client = AsyncMock()
            mock_factory.get_conversation_client.return_value = mock_client
            
            # Test that database factory can create clients
            client = mock_factory.get_conversation_client()
            assert client == mock_client

    @pytest.mark.batch
    @pytest.mark.unit
    def test_auth_utils_mock(self, mock_logger):
        """Test authentication utilities with mocks."""
        with patch('cwyodmodules.batch.utilities.chat_history.auth_utils.get_authenticated_user_details') as mock_auth:
            mock_auth.return_value = {
                "user_principal_id": "test-user-id",
                "user_name": "test-user",
                "user_email": "test@example.com"
            }
            
            # Test that auth utils can extract user details
            user_details = mock_auth(request_headers={"Authorization": "Bearer test-token"})
            assert user_details["user_principal_id"] == "test-user-id"
            assert user_details["user_name"] == "test-user"


class TestBatchDocumentProcessing:
    """Test class for batch document processing functionality."""

    @pytest.mark.batch
    @pytest.mark.unit
    def test_document_loading_mock(self, mock_logger):
        """Test document loading functionality with mocks."""
        # Mock document loading functionality
        mock_loader = Mock()
        mock_loader.load_document.return_value = {
            "content": "Test document content",
            "metadata": {"source": "test.pdf", "pages": 1}
        }
        
        # Test document loading
        document = mock_loader.load_document("test.pdf")
        assert document["content"] == "Test document content"
        assert document["metadata"]["source"] == "test.pdf"

    @pytest.mark.batch
    @pytest.mark.unit
    def test_document_chunking_mock(self, mock_logger):
        """Test document chunking functionality with mocks."""
        # Mock document chunking functionality
        mock_chunker = Mock()
        mock_chunker.chunk_document.return_value = [
            {"id": "chunk1", "content": "First chunk", "metadata": {"page": 1}},
            {"id": "chunk2", "content": "Second chunk", "metadata": {"page": 1}}
        ]
        
        # Test document chunking
        document_content = "This is a test document with multiple sentences. It should be chunked properly."
        chunks = mock_chunker.chunk_document(document_content, chunk_size=50)
        
        assert len(chunks) == 2
        assert chunks[0]["id"] == "chunk1"
        assert chunks[1]["id"] == "chunk2"

    @pytest.mark.batch
    @pytest.mark.unit
    def test_search_functionality_mock(self, mock_logger):
        """Test search functionality with mocks."""
        # Mock search functionality
        mock_searcher = Mock()
        mock_searcher.search.return_value = [
            {"id": "result1", "content": "Search result 1", "score": 0.95},
            {"id": "result2", "content": "Search result 2", "score": 0.85}
        ]
        
        # Test search
        query = "test query"
        results = mock_searcher.search(query, top_k=5)
        
        assert len(results) == 2
        assert results[0]["score"] == 0.95
        assert results[1]["score"] == 0.85


class TestBatchOrchestrator:
    """Test class for batch orchestrator functionality."""

    @pytest.mark.batch
    @pytest.mark.unit
    def test_orchestrator_mock(self, mock_logger):
        """Test orchestrator functionality with mocks."""
        # Mock orchestrator functionality
        mock_orchestrator = Mock()
        mock_orchestrator.process_document.return_value = {
            "status": "success",
            "chunks_created": 5,
            "entities_extracted": 10,
            "relationships_found": 8
        }
        
        # Test orchestrator
        document_path = "test_document.pdf"
        result = mock_orchestrator.process_document(document_path)
        
        assert result["status"] == "success"
        assert result["chunks_created"] == 5
        assert result["entities_extracted"] == 10

    @pytest.mark.batch
    @pytest.mark.unit
    def test_orchestrator_error_handling(self, mock_logger):
        """Test orchestrator error handling."""
        # Mock orchestrator with error
        mock_orchestrator = Mock()
        mock_orchestrator.process_document.side_effect = Exception("Processing error")
        
        # Test error handling
        with pytest.raises(Exception, match="Processing error"):
            mock_orchestrator.process_document("test_document.pdf")


class TestBatchIntegration:
    """Integration tests for batch utilities."""

    @pytest.mark.batch
    @pytest.mark.integration
    def test_full_document_processing_pipeline(self, mock_logger):
        """Test complete document processing pipeline."""
        # Mock the entire pipeline
        with patch('cwyodmodules.batch.utilities.document_loading') as mock_loading:
            with patch('cwyodmodules.batch.utilities.document_chunking') as mock_chunking:
                with patch('cwyodmodules.batch.utilities.search') as mock_search:
                    with patch('cwyodmodules.batch.utilities.orchestrator') as mock_orchestrator:
                        # Setup mocks
                        mock_loader = Mock()
                        mock_loader.load_document.return_value = {
                            "content": "Test document content",
                            "metadata": {"source": "test.pdf"}
                        }
                        mock_loading.get_loader.return_value = mock_loader
                        
                        mock_chunker = Mock()
                        mock_chunker.chunk_document.return_value = [
                            {"id": "chunk1", "content": "Test chunk"}
                        ]
                        mock_chunking.get_chunker.return_value = mock_chunker
                        
                        mock_searcher = Mock()
                        mock_searcher.search.return_value = [
                            {"id": "result1", "content": "Search result"}
                        ]
                        mock_search.get_searcher.return_value = mock_searcher
                        
                        mock_orchestrator_instance = Mock()
                        mock_orchestrator_instance.process_document.return_value = {
                            "status": "success",
                            "chunks": 1,
                            "entities": 2
                        }
                        mock_orchestrator.get_orchestrator.return_value = mock_orchestrator_instance
                        
                        # Execute pipeline
                        document_path = "test_document.pdf"
                        
                        # Load document
                        loader = mock_loading.get_loader()
                        document = loader.load_document(document_path)
                        
                        # Chunk document
                        chunker = mock_chunking.get_chunker()
                        chunks = chunker.chunk_document(document["content"])
                        
                        # Process with orchestrator
                        orchestrator = mock_orchestrator.get_orchestrator()
                        result = orchestrator.process_document(document_path)
                        
                        # Assert
                        assert document["content"] == "Test document content"
                        assert len(chunks) == 1
                        assert result["status"] == "success"

    @pytest.mark.batch
    @pytest.mark.integration
    def test_chat_history_integration(self, mock_logger):
        """Test chat history integration."""
        with patch('cwyodmodules.batch.utilities.chat_history.database_factory.DatabaseFactory') as mock_factory:
            with patch('cwyodmodules.batch.utilities.chat_history.auth_utils.get_authenticated_user_details') as mock_auth:
                # Setup mocks
                mock_client = AsyncMock()
                mock_client.get_conversations.return_value = [
                    {"id": "conv1", "title": "Test Conversation"}
                ]
                mock_factory.get_conversation_client.return_value = mock_client
                
                mock_auth.return_value = {"user_principal_id": "test-user"}
                
                # Test integration
                client = mock_factory.get_conversation_client()
                user_details = mock_auth(request_headers={"Authorization": "Bearer test-token"})
                
                # Simulate getting conversations
                conversations = client.get_conversations(user_details["user_principal_id"])
                
                # Assert
                assert len(conversations) == 1
                assert conversations[0]["id"] == "conv1"
                assert user_details["user_principal_id"] == "test-user"


class TestBatchErrorHandling:
    """Test error handling in batch utilities."""

    @pytest.mark.batch
    @pytest.mark.unit
    def test_database_connection_error(self, mock_logger):
        """Test database connection error handling."""
        with patch('cwyodmodules.batch.utilities.chat_history.database_factory.DatabaseFactory') as mock_factory:
            mock_client = AsyncMock()
            mock_client.connect.side_effect = Exception("Connection failed")
            mock_factory.get_conversation_client.return_value = mock_client
            
            # Test error handling
            client = mock_factory.get_conversation_client()
            with pytest.raises(Exception, match="Connection failed"):
                client.connect()

    @pytest.mark.batch
    @pytest.mark.unit
    def test_document_processing_error(self, mock_logger):
        """Test document processing error handling."""
        # Mock document processing with error
        mock_processor = Mock()
        mock_processor.process.side_effect = Exception("Processing failed")
        
        # Test error handling
        with pytest.raises(Exception, match="Processing failed"):
            mock_processor.process("test_document.pdf")

    @pytest.mark.batch
    @pytest.mark.unit
    def test_search_error(self, mock_logger):
        """Test search error handling."""
        # Mock search with error
        mock_searcher = Mock()
        mock_searcher.search.side_effect = Exception("Search failed")
        
        # Test error handling
        with pytest.raises(Exception, match="Search failed"):
            mock_searcher.search("test query")

==> cwyodmodules-0.3.87.tar.gz: cwyodmodules-0.3.87/tests/test_batch.py <==
"""
Tests for the batch utilities module.
"""
import pytest
from unittest.mock import Mock, AsyncMock, patch, MagicMock
import os
from typing import Dict, Any, List

# Import batch utilities - we'll test the structure and mock the actual implementations
# since the actual implementations may have complex dependencies


class TestBatchUtilitiesStructure:
    """Test class for batch utilities structure and basic functionality."""

    @pytest.mark.batch
    @pytest.mark.unit
    def test_batch_utilities_imports(self):
        """Test that batch utilities can be imported."""
        # Test that the main batch utilities module can be imported
        try:
            import cwyodmodules.batch.utilities
            assert True
        except ImportError as e:
            pytest.fail(f"Failed to import batch utilities: {e}")

    @pytest.mark.batch
    @pytest.mark.unit
    def test_helpers_structure(self):
        """Test helpers module structure."""
        try:
            import cwyodmodules.batch.utilities.helpers
            assert True
        except ImportError as e:
            pytest.fail(f"Failed to import helpers: {e}")

    @pytest.mark.batch
    @pytest.mark.unit
    def test_chat_history_structure(self):
        """Test chat history module structure."""
        try:
            import cwyodmodules.batch.utilities.chat_history
            assert True
        except ImportError as e:
            pytest.fail(f"Failed to import chat history: {e}")

    @pytest.mark.batch
    @pytest.mark.unit
    def test_document_loading_structure(self):
        """Test document loading module structure."""
        try:
            import cwyodmodules.batch.utilities.document_loading
            assert True
        except ImportError as e:
            pytest.fail(f"Failed to import document loading: {e}")

    @pytest.mark.batch
    @pytest.mark.unit
    def test_document_chunking_structure(self):
        """Test document chunking module structure."""
        try:
            import cwyodmodules.batch.utilities.document_chunking
            assert True
        except ImportError as e:
            pytest.fail(f"Failed to import document chunking: {e}")

    @pytest.mark.batch
    @pytest.mark.unit
    def test_search_structure(self):
        """Test search module structure."""
        try:
            import cwyodmodules.batch.utilities.search
            assert True
        except ImportError as e:
            pytest.fail(f"Failed to import search: {e}")

    @pytest.mark.batch
    @pytest.mark.unit
    def test_orchestrator_structure(self):
        """Test orchestrator module structure."""
        try:
            import cwyodmodules.batch.utilities.orchestrator
            assert True
        except ImportError as e:
            pytest.fail(f"Failed to import orchestrator: {e}")


class TestBatchHelpers:
    """Test class for batch helper functions."""

    @pytest.mark.batch
    @pytest.mark.unit
    def test_config_helper_mock(self, mock_logger):
        """Test config helper functionality with mocks."""
        with patch('cwyodmodules.batch.utilities.helpers.config.config_helper.ConfigHelper') as mock_config_helper:
            mock_config = Mock()
            mock_config.enable_chat_history = True
            mock_config_helper.get_active_config_or_default.return_value = mock_config
            
            # Test that config helper can be called
            config = mock_config_helper.get_active_config_or_default()
            assert config.enable_chat_history is True

    @pytest.mark.batch
    @pytest.mark.unit
    def test_env_helper_mock(self, mock_logger):
        """Test environment helper functionality with mocks."""
        with patch('cwyodmodules.batch.utilities.helpers.env_helper.EnvHelper') as mock_env_helper_class:
            mock_env_helper = Mock()
            mock_env_helper.LOG_EXECUTION = True
            mock_env_helper.LOG_ARGS = True
            mock_env_helper.LOG_RESULT = True
            mock_env_helper.is_auth_type_keys.return_value = True
            mock_env_helper.AZURE_OPENAI_ENDPOINT = "https://test.openai.azure.com/"
            mock_env_helper.AZURE_OPENAI_API_VERSION = "2024-02-15-preview"
            mock_env_helper.AZURE_OPENAI_API_KEY = "test-key"
            
            mock_env_helper_class.return_value = mock_env_helper
            
            # Test that env helper can be instantiated and used
            env_helper = mock_env_helper_class()
            assert env_helper.LOG_EXECUTION is True
            assert env_helper.is_auth_type_keys() is True
            assert env_helper.AZURE_OPENAI_ENDPOINT == "https://test.openai.azure.com/"


class TestBatchChatHistory:
    """Test class for batch chat history functionality."""

    @pytest.mark.batch
    @pytest.mark.unit
    def test_database_factory_mock(self, mock_logger):
        """Test database factory functionality with mocks."""
        with patch('cwyodmodules.batch.utilities.chat_history.database_factory.DatabaseFactory') as mock_factory:
            mock_client = AsyncMock()
            mock_factory.get_conversation_client.return_value = mock_client
            
            # Test that database factory can create clients
            client = mock_factory.get_conversation_client()
            assert client == mock_client

    @pytest.mark.batch
    @pytest.mark.unit
    def test_auth_utils_mock(self, mock_logger):
        """Test authentication utilities with mocks."""
        with patch('cwyodmodules.batch.utilities.chat_history.auth_utils.get_authenticated_user_details') as mock_auth:
            mock_auth.return_value = {
                "user_principal_id": "test-user-id",
                "user_name": "test-user",
                "user_email": "test@example.com"
            }
            
            # Test that auth utils can extract user details
            user_details = mock_auth(request_headers={"Authorization": "Bearer test-token"})
            assert user_details["user_principal_id"] == "test-user-id"
            assert user_details["user_name"] == "test-user"


class TestBatchDocumentProcessing:
    """Test class for batch document processing functionality."""

    @pytest.mark.batch
    @pytest.mark.unit
    def test_document_loading_mock(self, mock_logger):
        """Test document loading functionality with mocks."""
        # Mock document loading functionality
        mock_loader = Mock()
        mock_loader.load_document.return_value = {
            "content": "Test document content",
            "metadata": {"source": "test.pdf", "pages": 1}
        }
        
        # Test document loading
        document = mock_loader.load_document("test.pdf")
        assert document["content"] == "Test document content"
        assert document["metadata"]["source"] == "test.pdf"

    @pytest.mark.batch
    @pytest.mark.unit
    def test_document_chunking_mock(self, mock_logger):
        """Test document chunking functionality with mocks."""
        # Mock document chunking functionality
        mock_chunker = Mock()
        mock_chunker.chunk_document.return_value = [
            {"id": "chunk1", "content": "First chunk", "metadata": {"page": 1}},
            {"id": "chunk2", "content": "Second chunk", "metadata": {"page": 1}}
        ]
        
        # Test document chunking
        document_content = "This is a test document with multiple sentences. It should be chunked properly."
        chunks = mock_chunker.chunk_document(document_content, chunk_size=50)
        
        assert len(chunks) == 2
        assert chunks[0]["id"] == "chunk1"
        assert chunks[1]["id"] == "chunk2"

    @pytest.mark.batch
    @pytest.mark.unit
    def test_search_functionality_mock(self, mock_logger):
        """Test search functionality with mocks."""
        # Mock search functionality
        mock_searcher = Mock()
        mock_searcher.search.return_value = [
            {"id": "result1", "content": "Search result 1", "score": 0.95},
            {"id": "result2", "content": "Search result 2", "score": 0.85}
        ]
        
        # Test search
        query = "test query"
        results = mock_searcher.search(query, top_k=5)
        
        assert len(results) == 2
        assert results[0]["score"] == 0.95
        assert results[1]["score"] == 0.85


class TestBatchOrchestrator:
    """Test class for batch orchestrator functionality."""

    @pytest.mark.batch
    @pytest.mark.unit
    def test_orchestrator_mock(self, mock_logger):
        """Test orchestrator functionality with mocks."""
        # Mock orchestrator functionality
        mock_orchestrator = Mock()
        mock_orchestrator.process_document.return_value = {
            "status": "success",
            "chunks_created": 5,
            "entities_extracted": 10,
            "relationships_found": 8
        }
        
        # Test orchestrator
        document_path = "test_document.pdf"
        result = mock_orchestrator.process_document(document_path)
        
        assert result["status"] == "success"
        assert result["chunks_created"] == 5
        assert result["entities_extracted"] == 10

    @pytest.mark.batch
    @pytest.mark.unit
    def test_orchestrator_error_handling(self, mock_logger):
        """Test orchestrator error handling."""
        # Mock orchestrator with error
        mock_orchestrator = Mock()
        mock_orchestrator.process_document.side_effect = Exception("Processing error")
        
        # Test error handling
        with pytest.raises(Exception, match="Processing error"):
            mock_orchestrator.process_document("test_document.pdf")


class TestBatchIntegration:
    """Integration tests for batch utilities."""

    @pytest.mark.batch
    @pytest.mark.integration
    def test_full_document_processing_pipeline(self, mock_logger):
        """Test complete document processing pipeline."""
        # Mock the entire pipeline
        with patch('cwyodmodules.batch.utilities.document_loading') as mock_loading:
            with patch('cwyodmodules.batch.utilities.document_chunking') as mock_chunking:
                with patch('cwyodmodules.batch.utilities.search') as mock_search:
                    with patch('cwyodmodules.batch.utilities.orchestrator') as mock_orchestrator:
                        # Setup mocks
                        mock_loader = Mock()
                        mock_loader.load_document.return_value = {
                            "content": "Test document content",
                            "metadata": {"source": "test.pdf"}
                        }
                        mock_loading.get_loader.return_value = mock_loader
                        
                        mock_chunker = Mock()
                        mock_chunker.chunk_document.return_value = [
                            {"id": "chunk1", "content": "Test chunk"}
                        ]
                        mock_chunking.get_chunker.return_value = mock_chunker
                        
                        mock_searcher = Mock()
                        mock_searcher.search.return_value = [
                            {"id": "result1", "content": "Search result"}
                        ]
                        mock_search.get_searcher.return_value = mock_searcher
                        
                        mock_orchestrator_instance = Mock()
                        mock_orchestrator_instance.process_document.return_value = {
                            "status": "success",
                            "chunks": 1,
                            "entities": 2
                        }
                        mock_orchestrator.SemanticKernelOrchestrator.return_value = mock_orchestrator_instance
                        
                        # Execute pipeline
                        document_path = "test_document.pdf"
                        
                        # Load document
                        loader = mock_loading.get_loader()
                        document = loader.load_document(document_path)
                        
                        # Chunk document
                        chunker = mock_chunking.get_chunker()
                        chunks = chunker.chunk_document(document["content"])
                        
                        # Process with orchestrator
                        orchestrator = mock_orchestrator.SemanticKernelOrchestrator()
                        result = orchestrator.process_document(document_path)
                        
                        # Assert
                        assert document["content"] == "Test document content"
                        assert len(chunks) == 1
                        assert result["status"] == "success"

    @pytest.mark.batch
    @pytest.mark.integration
    def test_chat_history_integration(self, mock_logger):
        """Test chat history integration."""
        with patch('cwyodmodules.batch.utilities.chat_history.database_factory.DatabaseFactory') as mock_factory:
            with patch('cwyodmodules.batch.utilities.chat_history.auth_utils.get_authenticated_user_details') as mock_auth:
                # Setup mocks
                mock_client = AsyncMock()
                mock_client.get_conversations.return_value = [
                    {"id": "conv1", "title": "Test Conversation"}
                ]
                mock_factory.get_conversation_client.return_value = mock_client
                
                mock_auth.return_value = {"user_principal_id": "test-user"}
                
                # Test integration
                client = mock_factory.get_conversation_client()
                user_details = mock_auth(request_headers={"Authorization": "Bearer test-token"})
                
                # Simulate getting conversations
                conversations = client.get_conversations(user_details["user_principal_id"])
                
                # Assert
                assert len(conversations) == 1
                assert conversations[0]["id"] == "conv1"
                assert user_details["user_principal_id"] == "test-user"


class TestBatchErrorHandling:
    """Test error handling in batch utilities."""

    @pytest.mark.batch
    @pytest.mark.unit
    def test_database_connection_error(self, mock_logger):
        """Test database connection error handling."""
        with patch('cwyodmodules.batch.utilities.chat_history.database_factory.DatabaseFactory') as mock_factory:
            mock_client = AsyncMock()
            mock_client.connect.side_effect = Exception("Connection failed")
            mock_factory.get_conversation_client.return_value = mock_client
            
            # Test error handling
            client = mock_factory.get_conversation_client()
            with pytest.raises(Exception, match="Connection failed"):
                client.connect()

    @pytest.mark.batch
    @pytest.mark.unit
    def test_document_processing_error(self, mock_logger):
        """Test document processing error handling."""
        # Mock document processing with error
        mock_processor = Mock()
        mock_processor.process.side_effect = Exception("Processing failed")
        
        # Test error handling
        with pytest.raises(Exception, match="Processing failed"):
            mock_processor.process("test_document.pdf")

    @pytest.mark.batch
    @pytest.mark.unit
    def test_search_error(self, mock_logger):
        """Test search error handling."""
        # Mock search with error
        mock_searcher = Mock()
        mock_searcher.search.side_effect = Exception("Search failed")
        
        # Test error handling
        with pytest.raises(Exception, match="Search failed"):
            mock_searcher.search("test query")
